#ifndef NT2_INCLUDE_CONSTANTS_ELEVEN_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_ELEVEN_HPP_INCLUDED

#include <nt2/constant/include/constants/eleven.hpp>

#endif
